==> cpg-core-7.1.2-sources.jar: de/fraunhofer/aisec/cpg/graph/declarations/ConstructorDeclaration.kt <==
/*
 * Copyright (c) 2020, Fraunhofer AISEC. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *                    $$$$$$\  $$$$$$$\   $$$$$$\
 *                   $$  __$$\ $$  __$$\ $$  __$$\
 *                   $$ /  \__|$$ |  $$ |$$ /  \__|
 *                   $$ |      $$$$$$$  |$$ |$$$$\
 *                   $$ |      $$  ____/ $$ |\_$$ |
 *                   $$ |  $$\ $$ |      $$ |  $$ |
 *                   \$$$$$   |$$ |      \$$$$$   |
 *                    \______/ \__|       \______/
 *
 */
package de.fraunhofer.aisec.cpg.graph.declarations

import de.fraunhofer.aisec.cpg.graph.parseType

/**
 * The declaration of a constructor within a [RecordDeclaration]. Is it essentially a special case
 * of a [MethodDeclaration].
 */
class ConstructorDeclaration : MethodDeclaration() {
    // constructors always have implicitly the return type of their class
    override var recordDeclaration: RecordDeclaration?
        get() = super.recordDeclaration
        set(recordDeclaration) {
            super.recordDeclaration = recordDeclaration
            if (recordDeclaration != null) {
                // constructors always have implicitly the return type of their class
                returnTypes = listOf(parseType(recordDeclaration.name))
            }
        }
}

==> cpg-core-8.3.0-sources.jar: de/fraunhofer/aisec/cpg/graph/declarations/ConstructorDeclaration.kt <==
/*
 * Copyright (c) 2020, Fraunhofer AISEC. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *                    $$$$$$\  $$$$$$$\   $$$$$$\
 *                   $$  __$$\ $$  __$$\ $$  __$$\
 *                   $$ /  \__|$$ |  $$ |$$ /  \__|
 *                   $$ |      $$$$$$$  |$$ |$$$$\
 *                   $$ |      $$  ____/ $$ |\_$$ |
 *                   $$ |  $$\ $$ |      $$ |  $$ |
 *                   \$$$$$   |$$ |      \$$$$$   |
 *                    \______/ \__|       \______/
 *
 */
package de.fraunhofer.aisec.cpg.graph.declarations

/**
 * The declaration of a constructor within a [RecordDeclaration]. Is it essentially a special case
 * of a [MethodDeclaration].
 */
class ConstructorDeclaration : MethodDeclaration() {
    // constructors always have implicitly the return type of their class
    override var recordDeclaration: RecordDeclaration?
        get() = super.recordDeclaration
        set(recordDeclaration) {
            super.recordDeclaration = recordDeclaration
            if (recordDeclaration != null) {
                // constructors always have implicitly the return type of their class
                returnTypes = listOf(recordDeclaration.toType())
            }
        }
}
